---
title: H5 utils.
---

This module contains all necessary functions to work direct with h5 files

<!-- prettier-ignore -->
::: dh5.dh5_class.h5py_utils
    options:
      show_bases: false
      show_root_heading: false
      summary: false
